@@ -47,8 +47,7 @@ view.SetColorEdges(True)
 theme = vtkViewTheme.CreateMellowTheme()
 view.ApplyViewTheme(theme)
 
-window = vtkRenderWindow()
-window.SetSize(600, 600)
-view.SetupRenderWindow(window)
-view.GetRenderer().ResetCamera()
-window.GetInteractor().Start()
+view.GetRenderWindow().SetSize(600, 600)
+view.ResetCamera()
+view.Render()
+view.GetInteractor().Start()
