@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCell3D.cxx,v $
+  Module:    vtkCell3D.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -24,7 +24,6 @@
 #include "vtkCellArray.h"
 #include "vtkDoubleArray.h"
 
-vtkCxxRevisionMacro(vtkCell3D, "$Revision: 1.2 $");
 
 vtkCell3D::vtkCell3D()
 {
@@ -51,7 +50,7 @@ vtkCell3D::~vtkCell3D()
 }
 
 void vtkCell3D::Contour(double value, vtkDataArray *cellScalars, 
-                        vtkPointLocator *locator, vtkCellArray *verts, 
+                        vtkIncrementalPointLocator *locator, vtkCellArray *verts,
                         vtkCellArray *lines, vtkCellArray *polys,
                         vtkPointData *inPd, vtkPointData *outPd,
                         vtkCellData *inCd, vtkIdType cellId, vtkCellData *outCd)
@@ -216,7 +215,7 @@ void vtkCell3D::Contour(double value, vtkDataArray *cellScalars,
 }
 
 void vtkCell3D::Clip(double value, vtkDataArray *cellScalars, 
-                     vtkPointLocator *locator, vtkCellArray *tets,
+                     vtkIncrementalPointLocator *locator, vtkCellArray *tets,
                      vtkPointData *inPD, vtkPointData *outPD,
                      vtkCellData *inCD, vtkIdType cellId,
                      vtkCellData *outCD, int insideOut)
