@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPolygon.cxx,v $
+  Module:    vtkPolygon.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -30,7 +30,6 @@
 #include "vtkIncrementalPointLocator.h"
 #include "vtkSmartPointer.h"
 
-vtkCxxRevisionMacro(vtkPolygon, "$Revision: 1.12 $");
 vtkStandardNewMacro(vtkPolygon);
 
 //----------------------------------------------------------------------------
