@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkVoxel.cxx,v $
+  Module:    vtkVoxel.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -21,11 +21,10 @@
 #include "vtkObjectFactory.h"
 #include "vtkPixel.h"
 #include "vtkPointData.h"
-#include "vtkPointLocator.h"
+#include "vtkIncrementalPointLocator.h"
 #include "vtkPoints.h"
 #include "vtkBox.h"
 
-vtkCxxRevisionMacro(vtkVoxel, "$Revision: 1.4 $");
 vtkStandardNewMacro(vtkVoxel);
 
 //----------------------------------------------------------------------------
@@ -295,7 +294,7 @@ static int faces[6][4] = { {2,0,6,4}, {1,3,5,7},
 #include "vtkMarchingCubesCases.h"
 
 void vtkVoxel::Contour(double value, vtkDataArray *cellScalars, 
-                       vtkPointLocator *locator,
+                       vtkIncrementalPointLocator *locator,
                        vtkCellArray *verts, 
                        vtkCellArray *lines, 
                        vtkCellArray *polys,
