@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkQtLineChartView.h,v $
+  Module:    vtkQtLineChartView.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -40,7 +40,7 @@ Q_OBJECT
 
 public:
   static vtkQtLineChartView *New();
-  vtkTypeRevisionMacro(vtkQtLineChartView, vtkQtChartView);
+  vtkTypeMacro(vtkQtLineChartView, vtkQtChartView);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
