@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkQtTableView.cxx,v $
+  Module:    vtkQtTableView.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -49,7 +49,6 @@
 #include "vtkTable.h"
 #include "vtkViewTheme.h"
 
-vtkCxxRevisionMacro(vtkQtTableView, "$Revision: 1.22 $");
 vtkStandardNewMacro(vtkQtTableView);
 
 //----------------------------------------------------------------------------
