@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkBridgeCell.h,v $
+  Module:    vtkBridgeCell.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -33,7 +33,7 @@ class VTK_BRIDGE_EXPORT vtkBridgeCell : public vtkGenericAdaptorCell
 {
 public:
   static vtkBridgeCell *New();
-  vtkTypeRevisionMacro(vtkBridgeCell,vtkGenericAdaptorCell);
+  vtkTypeMacro(vtkBridgeCell,vtkGenericAdaptorCell);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
