@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCellDataToPointData.cxx,v $
+  Module:    vtkCellDataToPointData.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtkObjectFactory.h"
 #include "vtkPointData.h"
 
-vtkCxxRevisionMacro(vtkCellDataToPointData, "$Revision: 1.37 $");
 vtkStandardNewMacro(vtkCellDataToPointData);
 
 //----------------------------------------------------------------------------
@@ -95,7 +94,7 @@ int vtkCellDataToPointData::RequestData(
 
     input->GetPointCells(ptId, cellIds);
     numCells = cellIds->GetNumberOfIds();
-    if ( numCells > 0 )
+    if ( numCells > 0 && numCells < VTK_MAX_CELLS_PER_POINT )
       {
       weight = 1.0 / numCells;
       for (cellId=0; cellId < numCells; cellId++)
