@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkEnSightGoldReader.cxx,v $
+  Module:    vtkEnSightGoldReader.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -31,7 +31,6 @@
 #include <vtkstd/string>
 #include <vtkstd/vector>
 
-vtkCxxRevisionMacro(vtkEnSightGoldReader, "$Revision: 1.65 $");
 vtkStandardNewMacro(vtkEnSightGoldReader);
 
 //BTX
@@ -70,6 +69,15 @@ int vtkEnSightGoldReader::ReadGeometryFile(const char* fileName, int timeStep,
   int partId, realId, i;
   int lineRead;
   
+  // init line and subLine in case ReadLine(.), ReadNextDataLine(.), or
+  // sscanf(...) fails while strncmp(..) is still subsequently performed
+  // on these two un-assigned char arrays to cause memory leakage, as
+  // detected by Valgrind. As an example, VTKData/Data/EnSight/test.geo
+  // makes the first sscanf(...) below fail to assign 'subLine' that is
+  // though then accessed by strnmp(..) for comparing two char arrays.
+  line[0]    = '\0';
+  subLine[0] = '\0';
+  
   // Initialize
   //
   if (!fileName)
@@ -93,40 +101,66 @@ int vtkEnSightGoldReader::ReadGeometryFile(const char* fileName, int timeStep,
     sfilename = fileName;
     }
   
-  this->IS = new ifstream(sfilename.c_str(), ios::in);
-  if (this->IS->fail())
+  // In-file forward time step shifting 
+  // for accelerated data loading (bug #9289)
+  if (    this->UseFileSets
+       && this->ForwardTimeStepShiftIS
+       && this->ForwardTimeStepShiftMode
+     )
     {
-    vtkErrorMacro("Unable to open file: " << sfilename.c_str());
-    delete this->IS;
-    this->IS = NULL;
-    return 0;
-    }
-  
-  this->ReadNextDataLine(line);
-  sscanf(line, " %*s %s", subLine);
-  if (strncmp(subLine, "Binary",6) == 0)
-    {
-    vtkErrorMacro("This is a binary data set. Try "
-                  <<"vtkEnSightGoldBinaryReader.");
-    return 0;
-    }
-  
-  if (this->UseFileSets)
-    {
-    for (i = 0; i < timeStep - 1; i++)
+    this->IS = this->ForwardTimeStepShiftIS;
+    for ( i = this->PreviousTimeStepInFile; i < timeStep - 1; i ++ )
       {
-      while (strncmp(line, "END TIME STEP", 13) != 0)
+      while (  strncmp( line, "END TIME STEP", 13 ) != 0  )
         {
-        this->ReadLine(line);
+        this->ReadLine( line );
         }
-      this->ReadLine(line);
+      this->ReadLine( line );
       }
-    
-    while(strncmp(line, "BEGIN TIME STEP", 15) != 0)
+        
+    while (  strncmp( line, "BEGIN TIME STEP", 15 ) != 0  )
       {
-      this->ReadNextDataLine(line);
+      this->ReadNextDataLine( line );
+      }
+    this->ReadLine( line );
+    }
+  else
+    {
+    this->IS = new ifstream( sfilename.c_str(), ios::in ); 
+    if ( this->IS->fail() )
+      {
+      vtkErrorMacro( "Unable to open file: " << sfilename.c_str() );
+      delete this->IS;
+      this->IS = NULL;
+      return 0;
+      }
+  
+    this->ReadNextDataLine( line );
+    sscanf( line, " %*s %s", subLine );
+    if (  strncmp( subLine, "Binary", 6 ) == 0  )
+      {
+      vtkErrorMacro( "This is a binary data set. Try "
+                     << "vtkEnSightGoldBinaryReader." );
+      return 0;
+      }
+  
+    if ( this->UseFileSets )
+      {
+      for ( i = 0; i < timeStep - 1; i ++ )
+        {
+        while (  strncmp( line, "END TIME STEP", 13 ) != 0  )
+          {
+          this->ReadLine( line );
+          }
+        this->ReadLine( line );
+        }
+    
+      while(  strncmp( line, "BEGIN TIME STEP", 15 ) != 0  )
+        {
+        this->ReadNextDataLine( line );
+        }
+      this->ReadLine( line );
       }
-    this->ReadLine(line);
     }
 
   // Skip description lines.  Using ReadLine instead of
@@ -226,6 +260,10 @@ int vtkEnSightGoldReader::ReadGeometryFile(const char* fileName, int timeStep,
       if (lineRead < 0)
         {
         free(name);
+        if (  this->ForwardTimeStepShiftMode  )
+          {
+          this->ForwardTimeStepShiftIS = NULL;
+          }                                    
         delete this->IS;
         this->IS = NULL;
         return 0;
@@ -234,8 +272,23 @@ int vtkEnSightGoldReader::ReadGeometryFile(const char* fileName, int timeStep,
     free(name);
     }
   
-  delete this->IS;
+  // In-file forward time step shifting 
+  // for accelerated data loading (bug #9289)
+  if ( !this->ForwardTimeStepShiftMode && this->ForwardTimeStepShiftIS )
+    {
+    delete this->ForwardTimeStepShiftIS;
+    this->ForwardTimeStepShiftIS = NULL;
+    }
+  this->ForwardTimeStepShiftIS = this->IS;
   this->IS = NULL;
+  if (    this->ForwardTimeStepShiftIS
+       && this->ForwardTimeStepShiftMode == FORWARD_TIME_STEP_SHIFT_END
+     )
+    {
+    delete this->ForwardTimeStepShiftIS;
+    this->ForwardTimeStepShiftIS = NULL;
+    }
+    
   return 1;
 }
 
