@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkLightingPainter.h,v $
+  Module:    vtkLightingPainter.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -24,7 +24,7 @@ class VTK_RENDERING_EXPORT vtkLightingPainter : public vtkPolyDataPainter
 {
 public:
   static vtkLightingPainter* New();
-  vtkTypeRevisionMacro(vtkLightingPainter, vtkPolyDataPainter);
+  vtkTypeMacro(vtkLightingPainter, vtkPolyDataPainter);
   void PrintSelf(ostream& os, vtkIndent indent);
 
 protected:
