@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: ParseOGLExt.cxx,v $
+  Module:    ParseOGLExt.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -564,12 +564,23 @@ static void WriteClassDeclarationGuts(ostream &hfile, int type)
                                                            iconst->GetValue()))
              == ConstantsAlreadyWritten.end())
           {
+          if(strcmp(iconst->GetName().c_str(),"TIMEOUT_IGNORED")==0)
+            {
+            // BCC/VS6/VS70 cannot digest this C99 macro
+            hfile << "#if !defined(__BORLANDC__) && (!defined(_MSC_VER) || (defined(_MSC_VER) && _MSC_VER>=1310))" << endl;
+            }
+          
+          
           hfile << "  const GLenum " << iconst->GetName().c_str()
                 << " = static_cast<GLenum>(" << iconst->GetValue().c_str() << ");" << endl;
 
           ConstantsAlreadyWritten.insert(vtkstd::make_pair(iconst->GetName(), 
                                                            iconst->GetValue()));
-          
+          if(strcmp(iconst->GetName().c_str(),"TIMEOUT_IGNORED")==0)
+            {
+            // really special case for non C99 compilers like BCC
+            hfile << "#endif /* only for C99 compilers */" << endl;
+            }
           }
         else
           {
@@ -634,12 +645,9 @@ static void WriteCode(ostream &hfile, ostream &cxxfile)
   hfile << "#include \"vtkWindows.h\"" << endl;
   hfile << "#include \"vtkOpenGL.h\"" << endl;
   hfile << "#include <stddef.h>" << endl << endl;
-  hfile << "//#ifdef __APPLE__" << endl
-        << "//#include <OpenGL/glu.h>" << endl
-        << "//#else" << endl
-        << "//#include <GL/glu.h>" << endl
-        << "//#endif" << endl << endl;
   hfile << "#ifdef VTK_USE_X" << endl
+        << "/* To prevent glx.h to include glxext.h from the OS */" << endl
+        << "#define GLX_GLXEXT_LEGACY" << endl
         << "#include <GL/glx.h>" << endl
         << "#endif" << endl << endl;
   hfile << "class vtkOpenGLExtensionManager;" << endl << endl;
@@ -675,6 +683,11 @@ static void WriteCode(ostream &hfile, ostream &cxxfile)
   hfile << "  typedef vtkTypeInt32 int32_t;" << endl;
   hfile << "  typedef vtkTypeInt64 int64_t;" << endl;
   hfile << "  typedef vtkTypeUInt64 uint64_t;" << endl;
+  // OpenGL 3.2 typedefs
+  hfile << "  typedef int64_t GLint64;" << endl;
+  hfile << "  typedef uint64_t GLuint64;" << endl;
+  hfile << "  typedef struct __GLsync *GLsync;" << endl;
+  
   ConstantsAlreadyWritten.clear();
   WriteClassDeclarationGuts(hfile, Extension::GL);
   hfile << endl << "  // Method to load functions for a particular extension.";
