@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: TestHandleWidget.cxx,v $
+  Module:    TestHandleWidget.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -13,7 +13,13 @@
 
 =========================================================================*/
 //
-// This example tests the vtkSliderWidget.
+// This example tests the vtkHandleWidget.
+//
+// The handle that you see is always constrained to lie on a plane (
+// defined by a vtkImplicitPlaneWidget2). It  goes to show that you can place 
+// constraints on the movement of the handle. You can move the plane around 
+// interactively. It exercises the class vtkBoundedPlanePointPlacer.
+
 
 #include "vtkConeSource.h"
 #include "vtkGlyph3D.h"
@@ -732,6 +738,7 @@ int TestHandleWidget( int argc, char *argv[] )
     }
 
   iren->Initialize();
+  renWin->Render();
   handleWidget->EnabledOn();
   planeWidget->EnabledOn();
   ren1->SetBackground(0.1, 0.2, 0.4);
